<?php
/**
 * Hero Content Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Hero Content section
$wp_customize->add_section( 'musicsong_pro_hero_content_section', array(
	'title'             => esc_html__( 'Hero Content','musicsong-pro' ),
	'description'       => esc_html__( 'Hero Content Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Hero Content content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_section_enable]', array(
	'default'			=> 	$options['hero_content_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[hero_content_section_enable]', array(
	'label'             => esc_html__( 'Hero Content Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_hero_content_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// hero_content subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_content_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[hero_content_subtitle]', array(
		'selector'            => '#featured-video .section-header p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[hero_content_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_hero_content_subtitle_partial',
    ) );
}

// Hero Content content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_content_type]', array(
	'default'          	=> $options['hero_content_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_hero_content_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'musicsong-pro' ),
	),
) );

// hero_content pages drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_content_page]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[hero_content_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_hero_content_section',
	'choices'			=> musicsong_pro_page_choices(),
	'active_callback'	=> 'musicsong_pro_is_hero_content_section_content_page_enable',
) ) );

// hero_content posts drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_content_post]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[hero_content_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_hero_content_section',
	'choices'			=> musicsong_pro_post_choices(),
	'active_callback'	=> 'musicsong_pro_is_hero_content_section_content_post_enable',
) ) );

// hero_content title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_content_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[hero_content_title]', array(
		'selector'            => '#featured-video .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[hero_content_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_hero_content_title_partial',
    ) );
}

// hero_content description setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['hero_content_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_description]', array(
	'label'           	=> esc_html__( 'Description', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[hero_content_description]', array(
		'selector'            => '#featured-video .section-content p',
		'settings'            => 'musicsong_pro_theme_options[hero_content_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_hero_content_description_partial',
    ) );
}

// hero_content btn title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[hero_content_btn_title]', array(
		'selector'            => '#featured-video .read-more a',
		'settings'            => 'musicsong_pro_theme_options[hero_content_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_hero_content_btn_title_partial',
    ) );
}

// hero_content btn link setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_content_custom_enable',
	'type'				=> 'url',
) );

// video url setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[hero_content_video]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[hero_content_video]', array(
	'label'           	=> esc_html__( 'Featured Video URL', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Input video url from youtube or media library.', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_hero_content_section',
	'active_callback' 	=> 'musicsong_pro_is_hero_content_section_enable',
	'type'				=> 'url',
) );