<?php
/**
 * Artists section
 *
 * This is the template for the content of artists section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_artists_section' ) ) :
    /**
    * Add artists section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_artists_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if artists is enabled on frontpage
        $artists_enable = apply_filters( 'musicsong_pro_section_status', true, 'artists_section_enable' );

        if ( true !== $artists_enable ) {
            return false;
        }
        // Get artists section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_artists_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render artists section now.
        musicsong_pro_render_artists_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_artists_section_details' ) ) :
    /**
    * artists section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input artists section details.
    */
    function musicsong_pro_get_artists_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $artists_content_type  = $options['artists_content_type'];
        $artists_count = ! empty( $options['artists_count'] ) ? $options['artists_count'] : 4;
        
        $content = array();
        switch ( $artists_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $position = array();
                $social = array();

                for ( $i = 1; $i <= $artists_count; $i++ ) {
                    if ( ! empty( $options['artists_content_page_' . $i] ) ) :
                        $page_ids[] = $options['artists_content_page_' . $i];
                        $position[] = ! empty( $options['artists_position_' . $i] ) ? $options['artists_position_' . $i] : '';
                        $social[]   = ! empty( $options['artists_social_' . $i] ) ? $options['artists_social_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $artists_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();
                $social = array();

                for ( $i = 1; $i <= $artists_count; $i++ ) {
                    if ( ! empty( $options['artists_content_post_' . $i] ) ) :
                        $post_ids[] = $options['artists_content_post_' . $i];
                        $position[] = ! empty( $options['artists_position_' . $i] ) ? $options['artists_position_' . $i] : '';
                        $social[]   = ! empty( $options['artists_social_' . $i] ) ? $options['artists_social_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $artists_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['artists_content_category'] ) ? $options['artists_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $artists_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $artists_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['title']        = ! empty( $options['artists_title_' . $i] ) ? $options['artists_title_' . $i] : '';
                    $custom['excerpt']      = ! empty( $options['artists_description_' . $i] ) ? $options['artists_description_' . $i] : '';
                    $custom['image']        = ! empty( $options['artists_image_' . $i] ) ? $options['artists_image_' . $i] : '';
                    $custom['url']          = ! empty( $options['artists_link_' . $i] ) ? $options['artists_link_' . $i] : '#.';
                    $custom['position']     = ! empty( $options['artists_position_' . $i] ) ? $options['artists_position_' . $i] : '';
                    $custom['social']     = ! empty( $options['artists_social_' . $i] ) ? $options['artists_social_' . $i] : '';


                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;


            default:
            break;
        }

        if ( 'custom' !== $artists_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = ( 'category' !== $artists_content_type && ! empty( $position[$i] ) ) ? $position[$i] : '';
                    $page_post['social']  = ( 'category' !== $artists_content_type && ! empty( $social[$i] ) ) ? $social[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 40 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// artists section content details.
add_filter( 'musicsong_pro_filter_artists_section_details', 'musicsong_pro_get_artists_section_details' );


if ( ! function_exists( 'musicsong_pro_render_artists_section' ) ) :
  /**
   * Start artists section
   *
   * @return string artists content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_artists_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $column = ! empty( $options['artists_column'] ) ? $options['artists_column'] : 'col-4';
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="team-members" class="relative page-section">
            <div class="wrapper">
                <?php if ( ! empty( $options['artists_title'] ) || ! empty( $options['artists_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['artists_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['artists_title'] ); ?></h2>
                        <?php endif;
                        
                        if ( ! empty( $options['artists_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['artists_subtitle'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <!-- supports col-1, col-2, col-3 and col-4 -->
                <div class="section-content clear <?php echo esc_attr( $column ); ?>">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div>
                            <?php endif; 

                            if ( ! empty( $content['title'] ) || ! empty( $content['position'] ) ) : ?>
                                <header class="entry-header">
                                    <?php if ( ! empty( $content['title'] ) ) : ?>
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    <?php endif; 

                                    if ( ! empty( $content['position'] ) ) : ?>
                                        <p><?php echo esc_html( $content['position'] ); ?></p>
                                    <?php endif; ?>
                                </header>
                            <?php endif; 

                            if ( ! empty( $content['social'] ) ) : 
                                $social = explode( '|', $content['social'] );
                                ?>
                                <div class="social-icons">
                                    <ul>
                                        <?php foreach( $social as $social_link ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url( $social_link ); ?>">
                                                    <?php echo musicsong_pro_return_social_icon( $social_link ); ?>
                                                </a>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div><!-- .social-icons -->
                            <?php endif; ?>
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->

                <?php if ( ! empty( $options['artists_btn_title'] ) && ! empty( $options['artists_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['artists_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['artists_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #band-members -->

    <?php }
endif;